<template>
  <InnerFriendMessage
    :current-use-id="userDetail?.userId"
    :useAccessPersonalInfo="useAccessPersonalInfo"
    @go-user-home-page="goUserHomePage"
    @click="handleClick"
    v-bind="props"
  ></InnerFriendMessage>
</template>

<script setup lang="ts">
import { useUser, useAccessPersonalInfo } from '@/hooks';
import { FriendMessage as InnerFriendMessage } from '@12333/components';
import { ListActionsType } from '@12333/hooks';
import { CircleFriendRelationalTypeEnum } from '@12333/constants';
import Taro from '@tarojs/taro';

defineOptions({
  name: 'FriendMessage',
});

type Props = {
  data: API.CircleFriendDto;
  groupIndex?: number;
  itemIndex?: number;
  listActions?: ListActionsType;
};

const props = withDefaults(defineProps<Props>(), {});

const { userDetail } = useUser();

const goUserHomePage = (userId: string) => {
  Taro.navigateTo({
    url: `${RouterPath.userHomePage}?userId=${userId}`,
  });
};

function handleClick() {
  if (props.data.relationalType == CircleFriendRelationalTypeEnum.Order) {
    Taro.navigateTo({
      url: `${RouterPath.orderDetail}?id=${props.data.relationalId}`,
    });
  } else if (props.data.relationalType == CircleFriendRelationalTypeEnum.Resource) {
    Taro.navigateTo({
      url: `${RouterPath.resourceDetail}?id=${props.data.relationalId}`,
    });
  }
}
</script>
